@@ -8,7 +8,7 @@
 #             Access to the db of overlays
 #
 # Copyright:
-#             (c) 2005 - 2006 Gunnar Wrobel
+#             (c) 2005 - 2008 Gunnar Wrobel
 #             Distributed under the terms of the GNU General Public License v2
 #
 # Author(s):
@@ -24,7 +24,7 @@ __version__ = "$Id: db.py 309 2007-04-09 16:23:38Z wrobel $"
 #
 #-------------------------------------------------------------------------------
 
-import os, codecs, os.path, urllib2, re, md5
+import os, codecs, os.path, urllib2, re, hashlib
 
 from   layman.utils             import path
 from   layman.overlay           import Overlays
@@ -60,7 +60,7 @@ class DB(Overlays):
 
         OUT.debug('DB handler initiated', 6)
 
-    def add(self, overlay):
+    def add(self, overlay, quiet = False):
         '''
         Add an overlay to the local list of overlays.
 
@@ -106,7 +106,7 @@ class DB(Overlays):
         '''
 
         if overlay.name not in self.overlays.keys():
-            result = overlay.add(self.config['storage'])
+            result = overlay.add(self.config['storage'], quiet)
             if result == 0:
                 if 'priority' in self.config.keys():
                     overlay.set_priority(self.config['priority'])
@@ -115,8 +115,11 @@ class DB(Overlays):
                 make_conf = MakeConf(self.config, self.overlays)
                 make_conf.add(overlay)
             else:
-                overlay.delete(self.config['storage'])
-                raise Exception('Adding the overlay failed!')
+                raise Exception('Adding the overlay failed! Possible remains of'
+                                ' the opration have NOT been removed and may be'
+                                ' left at ' + path([self.config['storage'],
+                                                  overlay.name]) + '. Please re'
+                                'move them manually if required.')
         else:
             raise Exception('Overlay "' + overlay.name + '" already in the loca'
                             'l list!')
@@ -182,13 +185,13 @@ class DB(Overlays):
         else:
             raise Exception('No local overlay named "' + overlay.name + '"!')
 
-    def sync(self, overlay_name):
+    def sync(self, overlay_name, quiet = False):
         '''Synchronize the given overlay.'''
 
         overlay = self.select(overlay_name)
 
         if overlay:
-            result = overlay.sync(self.config['storage'])
+            result = overlay.sync(self.config['storage'], quiet)
             if result:
                 raise Exception('Syncing overlay "' + overlay_name + 
                                 '" returned status ' + str(result) + '!')
@@ -318,7 +321,7 @@ class RemoteDB(Overlays):
 
         OUT.debug('Generating cache path.', 6)
 
-        return base + '_' + md5.md5(url).hexdigest() + '.xml'
+        return base + '_' + hashlib.md5(url).hexdigest() + '.xml'
 
 #===============================================================================
 #
@@ -332,7 +335,7 @@ class MakeConf:
 
     Check that an add/remove cycle does not modify the make.conf:
 
-    >>> import md5
+    >>> import hashlib
     >>> write = os.tmpnam()
     >>> here = os.path.dirname(os.path.realpath(__file__))
     >>> config = {'local_list' :
@@ -343,7 +346,7 @@ class MakeConf:
     ...           'quietness':3}
     >>> b = DB(config)
     >>> a = MakeConf(config, b.overlays)
-    >>> o_md5 = str(md5.md5(open(here + '/tests/testfiles/make.conf').read()).hexdigest())
+    >>> o_md5 = str(hashlib.md5(open(here + '/tests/testfiles/make.conf').read()).hexdigest())
     >>> a.path = write
     >>> a.add(b.overlays['wrobel-stable'])
     >>> [i.name for i in a.overlays]
@@ -358,7 +361,7 @@ class MakeConf:
     >>> [i.name for i in a.overlays]
     [u'wrobel', u'wrobel-stable']
     >>> a.delete(b.overlays['wrobel'])
-    >>> n_md5 = str(md5.md5(open(write).read()).hexdigest())
+    >>> n_md5 = str(hashlib.md5(open(write).read()).hexdigest())
     >>> o_md5 == n_md5
     True
     >>> os.unlink(write)
