@@ -8,7 +8,7 @@
 #             Handles darcs overlays
 #
 # Copyright:
-#             (c) 2005 - 2006 Gunnar Wrobel, Andres Loeh
+#             (c) 2005 - 2008 Gunnar Wrobel, Andres Loeh
 #             Distributed under the terms of the GNU General Public License v2
 #
 # Author(s):
@@ -41,7 +41,7 @@ class DarcsOverlay(Overlay):
 
     binary_command  = '/usr/bin/darcs'
 
-    def add(self, base):
+    def add(self, base, quiet = False):
         '''Add overlay.'''
 
         self.supported()
@@ -49,7 +49,7 @@ class DarcsOverlay(Overlay):
         return self.cmd(self.binary_command + ' get --partial "' + self.src +
                         '/" "' + path([base, self.name]) + '"')
 
-    def sync(self, base):
+    def sync(self, base, quiet = False):
         '''Sync overlay.'''
 
         self.supported()
